/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.flume;

import org.apache.flume.lifecycle.LifecycleAware;
import org.apache.flume.sink.PollableSinkRunner;

abstract public class SinkRunner implements LifecycleAware {

  private Sink sink;

  public static SinkRunner forSink(Sink sink) {
    SinkRunner runner = null;

    if (sink instanceof PollableSink) {
      runner = new PollableSinkRunner();
      ((PollableSinkRunner) runner).setSink((PollableSink) sink);
    } else {
      throw new IllegalArgumentException("No known runner type for sink "
          + sink);
    }

    return runner;
  }

  public Sink getSink() {
    return sink;
  }

  public void setSink(Sink sink) {
    this.sink = sink;
  }

}
